%define anolis_release 2
%bcond_with externalfuse

Name:           ntfs-3g
Epoch:          2
Version:        2022.10.3
Release:        %{anolis_release}%{?dist}
Summary:        Linux NTFS userspace driver
License:        GPLv2+
URL:            https://www.tuxera.com/company/open-source/
Source0:	https://github.com/tuxera/ntfs-3g/archive/refs/tags/%{version}.tar.gz

# https://github.com/tuxera/ntfs-3g/commit/75dcdc2cf37478fad6c0e3427403d198b554951d
Patch0: 0001-fix-cve-2023-52890.patch 

BuildRequires:  make
# ntfs-3g BuildRequires
BuildRequires:  gnutls-devel
BuildRequires:  libattr-devel
%if %{with externalfuse}
BuildRequires:  fuse-devel
Requires:       fuse
%endif
# ntfsprogs BuildRequires
BuildRequires:  libconfig-devel
BuildRequires:  libgcrypt-devel
BuildRequires:  libtool
BuildRequires:  libuuid-devel
Requires:       %{name}-libs = %{epoch}:%{version}-%{release}
Provides:       ntfsprogs-fuse = %{epoch}:%{version}-%{release}
Obsoletes:      ntfsprogs-fuse < %{epoch}:%{version}-%{release}
Provides:       fuse-ntfs-3g = %{epoch}:%{version}-%{release}
#Recommends:     ntfs-3g-system-compression

%description
NTFS-3G is a stable, open source, GPL licensed, POSIX, read/write NTFS
driver for Linux and many other operating systems. It provides safe
handling of the Windows XP, Windows Server 2003, Windows 2000, Windows
Vista, Windows Server 2008 and Windows 7 NTFS file systems. NTFS-3G can
create, remove, rename, move files, directories, hard links, and streams;
it can read and write normal and transparently compressed files, including
streams and sparse files; it can handle special files like symbolic links,
devices, and FIFOs, ACL, extended attributes; moreover it provides full
file access right and ownership support.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{epoch}:%{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package libs
Summary:        Runtime libraries for ntfs-3g

%description libs
Libraries for applications to use ntfs-3g functionality.

%package devel
Summary:        Development files and libraries for ntfs-3g
Requires:       %{name}-libs = %{epoch}:%{version}-%{release}
Provides:       ntfsprogs-devel = %{epoch}:%{version}-%{release}
# ntfsprogs-2.0.0-17 was never built. 2.0.0-16 was the last build for that
# standalone package.
Obsoletes:      ntfsprogs-devel < 2.0.0

%description devel
Headers and libraries for developing applications that use ntfs-3g
functionality.

%package -n ntfsprogs
Summary:        NTFS filesystem libraries and utilities
Requires:       %{name}-libs = %{epoch}:%{version}-%{release}
# We don't really provide this. This code is dead and buried now.
Provides:       ntfsprogs-gnomevfs = %{epoch}:%{version}-%{release}
Obsoletes:      ntfsprogs-gnomevfs < %{epoch}:%{version}-%{release}
# Needed to fix multilib issue
# standalone package.
Obsoletes:      ntfsprogs < 2.0.0

%description -n ntfsprogs
The ntfsprogs package currently consists of a library and utilities such as
mkntfs, ntfscat, ntfsls, ntfsresize, and ntfsundelete (for a full list of
included utilities see man 8 ntfsprogs after installation).

# Pass --with externalfuse to compile against system fuse lib
%prep
%autosetup -n %{name}-%{version}%{?subver} -p1


%build
./autogen.sh

CFLAGS="%{optflags} -D_FILE_OFFSET_BITS=64"
%configure \
	--disable-static \
	--disable-ldconfig \
%if %{with externalfuse}
	--with-fuse=external \
%endif
	--exec-prefix=/ \
	--enable-posix-acls \
	--enable-xattr-mappings \
	--enable-crypto \
	--enable-extras \
	--enable-quarantined
%make_build LIBTOOL=%{_bindir}/libtool


%install
%make_install LIBTOOL=%{_bindir}/libtool

rm -rf %{buildroot}%{_libdir}/*.a

rm -rf %{buildroot}/%{_sbindir}/mount.ntfs-3g
cp -a %{buildroot}/%{_bindir}/ntfs-3g %{buildroot}/%{_sbindir}/mount.ntfs-3g

# Actually make some symlinks for simplicity...
# ... since we're obsoleting ntfsprogs-fuse
pushd %{buildroot}/%{_bindir}
ln -s ntfs-3g ntfsmount
popd
pushd %{buildroot}/%{_sbindir}
ln -s mount.ntfs-3g mount.ntfs-fuse
# And since there is no other package in Fedora that provides an ntfs
# mount...
ln -s mount.ntfs-3g mount.ntfs
# Need this for fsck to find it
ln -s ../bin/ntfsck fsck.ntfs
popd

mv %{buildroot}/sbin/* %{buildroot}/%{_sbindir}
rmdir %{buildroot}/sbin

# We get this on our own, thanks.
rm -rf %{buildroot}%{_defaultdocdir}/%{name}/README

%generate_compatibility_deps

%files
%license COPYING
%{_sbindir}/mount.ntfs
%{_sbindir}/mount.ntfs-3g
%{_sbindir}/mount.ntfs-fuse
%{_sbindir}/mount.lowntfs-3g
%{_bindir}/ntfs-3g
%{_bindir}/ntfsmount
%{_bindir}/ntfs-3g.probe
%{_bindir}/lowntfs-3g
%{abidir}/ntfs-3g.probe-option.list
%{_mandir}/man8/mount.lowntfs-3g.*
%{_mandir}/man8/mount.ntfs-3g.*
%{_mandir}/man8/ntfs-3g*

%files doc
%doc AUTHORS ChangeLog CREDITS NEWS README

%files libs
%dir %{abidir}
%license COPYING
%{_libdir}/libntfs-3g.so.*
%{abidir}/libntfs-3g.dump

%files devel
%{_includedir}/ntfs-3g/
%{_libdir}/libntfs-3g.so
%{_libdir}/pkgconfig/libntfs-3g.pc

%files -n ntfsprogs
%doc AUTHORS CREDITS ChangeLog NEWS README
%license COPYING
%{_bindir}/ntfscat
%{_bindir}/ntfscluster
%{_bindir}/ntfscmp
%{_bindir}/ntfsfix
%{_bindir}/ntfsinfo
%{_bindir}/ntfsls
%{_bindir}/ntfssecaudit
%{_bindir}/ntfsusermap
# Extras
%{_bindir}/ntfsck
%{_bindir}/ntfsdecrypt
%{_bindir}/ntfsdump_logfile
%{_bindir}/ntfsfallocate
%{_bindir}/ntfsmftalloc
%{_bindir}/ntfsmove
%{_bindir}/ntfsrecover
%{_bindir}/ntfstruncate
%{_bindir}/ntfswipe
%{_sbindir}/fsck.ntfs
%{_sbindir}/mkfs.ntfs
%{_sbindir}/mkntfs
%{_sbindir}/ntfsclone
%{_sbindir}/ntfscp
%{_sbindir}/ntfslabel
%{_sbindir}/ntfsresize
%{_sbindir}/ntfsundelete
%{abidir}/mkntfs-option.list
%{abidir}/ntfscat-option.list
%{abidir}/ntfsclone-option.list
%{abidir}/ntfscluster-option.list
%{abidir}/ntfscp-option.list
%{abidir}/ntfsdecrypt-option.list
%{abidir}/ntfsfallocate-option.list
%{abidir}/ntfsfix-option.list
%{abidir}/ntfsinfo-option.list
%{abidir}/ntfslabel-option.list
%{abidir}/ntfsrecover-option.list
%{abidir}/ntfsresize-option.list
%{abidir}/ntfssecaudit-option.list
%{abidir}/ntfstruncate-option.list
%{abidir}/ntfsundelete-option.list
%{abidir}/ntfswipe-option.list
%{_mandir}/man8/mkntfs.8*
%{_mandir}/man8/mkfs.ntfs.8*
%{_mandir}/man8/ntfs[^m][^o]*.8*
%exclude %{_mandir}/man8/ntfs-3g*

%changelog
* Thu Jan 16 2025 yangxinyu <yangxinyu@nfschina.com> - 2:2022.10.3-2
- fix cve-2023-52890

* Sun Nov 27 2022 Funda Wang <fundawang@yeah.net> - 2:2022.10.3-1
- New version 2022.10.3

* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2:2022.5.17-2
- optimise spec file

* Mon Sep 5 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 2:2022.5.17-1
- update to 2022.5.17

* Fri Apr 15 2022 zhang xianting <zhangxianting@uniontech.com> - 2:2021.8.22-1
- Initial build for Anolis V23
